@@ -2,7 +2,26 @@
 
    Copyright (c) 1989-1991 Curtis McCauley, James E. Wilson
 
-   You may copy this subroutine package freely, modify it as you desire,
+   This file is part of Umoria.
+
+   Umoria is free software; you can redistribute it and/or modify 
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Umoria is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of 
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU Genral Public License for more details.
+
+   You should have received a copy of the GNU General Public License 
+   along with Umoria.  If not, see <http://www.gnu.org/licenses/>. */
+
+/* This file was also released as part of an independent program, and
+   may be redistributed and/or modified under the authors' original terms,
+   which are given below. */
+
+/* You may copy this subroutine package freely, modify it as you desire,
    and distribute it at will, as long as the copyright notice in the source
    material is not disturbed, excepting that no one may use this package or
    any part of it for commercial purposes of any kind without the express
